/***************************************************************************
                          region.C  -  description
                             -------------------
    begin                : Tue Aug 6 2002
    copyright            : (C) 2002 by David Brokenshire
    email                : brokenshire@sfu.ca
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "region.h"


/*! This method constructs the default region by setting both pointers to null.
    This does not create a valid region.
*/
Region::Region()
{
  rectangularRegion = NULL;
  circularRegion = NULL;
}

/*! This method constructs a region based on a rectangle.
*/
Region::Region(Rectangle* rect)
{
  Region();
  setArea(rect);
}

/*! This method constructs a region based on a circle
*/
Region::Region(Circle* circ)
{
  setArea(circ);
}

/*! Checks if a region is rectangular or circular.

    \return bool True if rectangular, false if circular
*/
bool Region::isRectangle() const
{
  return isRectangular;
}

/*! Checks if a region is rectangular or circular.

    \return bool True if circular, false if rectangular
*/

bool Region::isCircle() const
{
  return !isRectangular;
}

/*! Checks if a VecPosition is within the region.
    \param position VecPosition for some position
    \return bool true if the VecPosition is within the region
*/
bool Region::isInRegion(const VecPosition& position) const
{
  return isRectangular ? rectangularRegion->isInside(position) : circularRegion->isInside(position);
}

/*! Sets the defining area of the region to the passed Rectangle
*/
void Region::setArea(Rectangle *rect)
{
  isRectangular = true;
  rectangularRegion = rect;
}

/*! Sets the defining area of the region to the passed circle
*/
void Region::setArea(Circle *circ)
{
  isRectangular = false;
  circularRegion = circ;
}
